==> net.java.html.lib-0.2-sources.jar: net/java/html/lib/TypedPropertyDescriptor.java <==
package net.java.html.lib;
public class TypedPropertyDescriptor<T> extends net.java.html.lib.Objs {
  protected TypedPropertyDescriptor(net.java.html.lib.Objs.Constructor<?> c, java.lang.Object js) {
    super(c, js);
  }
  private static final class $Constructor extends net.java.html.lib.Objs.Constructor<TypedPropertyDescriptor> {
    $Constructor() {
      super(TypedPropertyDescriptor.class);
    }
    @Override
    public TypedPropertyDescriptor create(java.lang.Object obj) {
      return obj == null ? null : new TypedPropertyDescriptor(this, obj);
    }
  };
  private static final $Constructor $AS = new $Constructor();
  public static TypedPropertyDescriptor $as(java.lang.Object obj) {
    return $AS.create(obj);
  }
  public net.java.html.lib.Objs.Property<java.lang.Boolean> enumerable = net.java.html.lib.Objs.Property.create(this, java.lang.Boolean.class, "enumerable");
  public java.lang.Boolean enumerable() { return enumerable.get(); }
  public net.java.html.lib.Objs.Property<java.lang.Boolean> configurable = net.java.html.lib.Objs.Property.create(this, java.lang.Boolean.class, "configurable");
  public java.lang.Boolean configurable() { return configurable.get(); }
  public net.java.html.lib.Objs.Property<java.lang.Boolean> writable = net.java.html.lib.Objs.Property.create(this, java.lang.Boolean.class, "writable");
  public java.lang.Boolean writable() { return writable.get(); }
  public net.java.html.lib.Objs.Property<net.java.html.lib.Objs> value = net.java.html.lib.Objs.Property.create(this, net.java.html.lib.Objs.class, "value");
  public net.java.html.lib.Objs.Property<net.java.html.lib.Function.A0<? extends T>> get = net.java.html.lib.Objs.Property.create(this, net.java.html.lib.Function.A0.class, "get");
  public net.java.html.lib.Function.A0<? extends T> get() { return get.get(); }
  public net.java.html.lib.Objs.Property<net.java.html.lib.Function.A1<? super T,? extends java.lang.Void>> set = net.java.html.lib.Objs.Property.create(this, net.java.html.lib.Function.A1.class, "set");
  public net.java.html.lib.Function.A1<? super T,? extends java.lang.Void> set() { return set.get(); }
}

==> net.java.html.lib-0.16-sources.jar: net/java/html/lib/TypedPropertyDescriptor.java <==
package net.java.html.lib;
public class TypedPropertyDescriptor<T> extends net.java.html.lib.Objs {
  private final Class<?> type_T;
  protected TypedPropertyDescriptor(net.java.html.lib.Objs.Constructor<?> c, java.lang.Object js) {
    super(c, js);
    this.type_T = java.lang.Object.class;
  }
  protected TypedPropertyDescriptor(net.java.html.lib.Objs.Constructor<?> c, java.lang.Object js, java.lang.reflect.Type type_T) {
    super(c, js);
    this.type_T = (Class<?>)type_T;
  }
  private static final class $Constructor extends net.java.html.lib.Objs.Constructor<TypedPropertyDescriptor> {
    $Constructor() {
      super(TypedPropertyDescriptor.class);
    }
    @Override
    public TypedPropertyDescriptor create(java.lang.Object obj) {
      return obj == null ? null : new TypedPropertyDescriptor(this, obj);
    }
    @Override
    public TypedPropertyDescriptor create(java.lang.Object obj, java.lang.reflect.Type... typeParameters) {
      return obj == null ? null : new TypedPropertyDescriptor(this, obj, findType(typeParameters, 0));
    }
    private static java.lang.reflect.Type findType(java.lang.reflect.Type[] arr, int index) {
      return arr == null || arr.length <= index || arr[index] == null ? java.lang.Object.class : arr[index];
    }
  };
  private static final $Constructor $AS = new $Constructor();
  public static TypedPropertyDescriptor $as(java.lang.Object obj) {
    return $AS.create(obj);
  }
  public static TypedPropertyDescriptor $as(java.lang.Object obj, java.lang.reflect.Type... typeParameters) {
    return $AS.create(obj, typeParameters);
  }
  public net.java.html.lib.Objs.Property<java.lang.Boolean> enumerable = net.java.html.lib.Objs.Property.create(this, java.lang.Boolean.class, "enumerable");
  public java.lang.Boolean enumerable() { return enumerable.get(); }
  public net.java.html.lib.Objs.Property<java.lang.Boolean> configurable = net.java.html.lib.Objs.Property.create(this, java.lang.Boolean.class, "configurable");
  public java.lang.Boolean configurable() { return configurable.get(); }
  public net.java.html.lib.Objs.Property<java.lang.Boolean> writable = net.java.html.lib.Objs.Property.create(this, java.lang.Boolean.class, "writable");
  public java.lang.Boolean writable() { return writable.get(); }
  public net.java.html.lib.Objs.Property<net.java.html.lib.Objs> value = net.java.html.lib.Objs.Property.create(this, net.java.html.lib.Objs.class, "value");
  public net.java.html.lib.Objs.Property<net.java.html.lib.Function.A0<? extends T>> get = net.java.html.lib.Objs.Property.create(this, net.java.html.lib.Function.A0.class, "get");
  public net.java.html.lib.Function.A0<? extends T> get() { return get.get(); }
  public net.java.html.lib.Objs.Property<net.java.html.lib.Function.A1<? super T,? extends java.lang.Void>> set = net.java.html.lib.Objs.Property.create(this, net.java.html.lib.Function.A1.class, "set");
  public net.java.html.lib.Function.A1<? super T,? extends java.lang.Void> set() { return set.get(); }
}
